Package 'remart'

Title: Reimplementation of the 'biomaRt' Package Using Modern Ensembl APIs
Description: This package aims to offer a drop-in replacement to biomaRt using the same interface but the more modern and better maintained APIs provided by Ensembl.
Authors: Hugo Gruson [aut, cre] (ORCID: <https://orcid.org/0000-0002-4094-1476>), German Network for Bioinformatics Infrastructure - de.NBI [fnd]
Maintainer: Hugo Gruson <[email protected]>
License: MIT + file LICENSE
Version: 0.0.0.9000
Built: 2026-05-17 09:16:31 UTC
Source: https://github.com/Huber-group-EMBL/remart

Help Index


Retries gene annotation information from Ensembl.

Description

Retries gene annotation information from Ensembl.

Usage

getGene(id, type = "ensembl_gene_id", ...)

Arguments

id

vector of gene identifiers one wants to annotate

type

type of identifier, possible values can be obtained by the listFilters function. Examples are entrezgene_id, hgnc_symbol (for hugo gene symbol), ensembl_gene_id, unigene, agilentprobe, affy_hg_u133_plus_2, refseq_dna, etc.

...

Ignored. Used to catch no longer necessary parameters such as mart from biomaRt functions.

Examples

remart::getGene(
  "ENSG00000157764",
  type = "ensembl_gene_id"
)

ids <- c(
 "ENSG00000003987",
 "ENSG00000004939"
)
remart::getGene(
  id = ids,
  type = "ensembl_gene_id"
)

Get Sequences from Ensembl

Description

Get Sequences from Ensembl

Usage

getSequence(
  chromosome,
  start,
  end,
  id,
  type,
  seqType,
  upstream,
  downstream,
  ...
)

Arguments

chromosome

Chromosome name

start

start position of sequence on chromosome

end

end position of sequence on chromosome

id

An identifier or vector of identifiers.

type

The type of identifier used. Supported types are hugo, ensembl, embl, entrezgene, refseq, ensemblTrans and unigene. Alternatively one can also use a filter to specify the type. Possible filters are given by the listFilters() function.

seqType

Type of sequence that you want to retrieve. Allowed seqTypes are given in the details section.

upstream

To add the upstream sequence of a specified number of basepairs to the output.

downstream

To add the downstream sequence of a specified number of basepairs to the output.

...

Ignored. Used to catch no longer necessary parameters such as mart from biomaRt functions.

Examples

remart::getSequence(
  seqType = "gene_exon_intron",
  type = "ensembl_gene_id",
  id = "ENSG00000001497"
)

ids <- c(
 "ENSG00000003987",
 "ENSG00000004939"
)
remart::getSequence(
  seqType = "gene_exon_intron",
  type = "ensembl_gene_id",
  id = ids
)